import { EventEmitter, Injectable, NgModule, Optional, Output, Pipe, SkipSelf } from '@angular/core';
import { CommonModule } from '@angular/common';
import { HttpClient } from '@angular/common/http';
import { JwtHelper } from 'angular2-jwt';
import { Observable as Observable$1 } from 'rxjs/Observable';
import 'rxjs/add/observable/of';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var AuthenticationServiceConfig = (function () {
    function AuthenticationServiceConfig() {
    }
    return AuthenticationServiceConfig;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var EmailServiceConfig = (function () {
    function EmailServiceConfig() {
    }
    return EmailServiceConfig;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var EmployeeServiceConfig = (function () {
    function EmployeeServiceConfig() {
    }
    return EmployeeServiceConfig;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var SharePointServiceConfig = (function () {
    function SharePointServiceConfig() {
    }
    return SharePointServiceConfig;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
//#region Imports
var AuthenticationService = (function () {
    //#endregion
    //#region Lifecycle
    function AuthenticationService(config, http$$1) {
        this.http = http$$1;
        this.authenticatedChanged = new EventEmitter();
        this.authenticated = false;
        this.authenticationApiUrl = config.authenticationApiUrl;
    }
    //#endregion
    //#region Utilities
    /**
     * @param {?} sharePointService
     * @param {?} username
     * @param {?} password
     * @param {?=} adminGroup
     * @return {?}
     */
    AuthenticationService.prototype.login = /**
     * @param {?} sharePointService
     * @param {?} username
     * @param {?} password
     * @param {?=} adminGroup
     * @return {?}
     */
    function (sharePointService, username, password, adminGroup) {
        var _this = this;
        var /** @type {?} */ today = new Date();
        var /** @type {?} */ expiration = new Date().setFullYear(today.getFullYear() + 10);
        var /** @type {?} */ request = {
            username: username,
            password: password,
            adminGroup: adminGroup,
            expirationDate: expiration // moment().add(10, 'years').toDate()
        };
        this.http.post(this.authenticationApiUrl, request)
            .subscribe(function (token) { return _this.validateUser(sharePointService, token); });
    };
    /**
     * @return {?}
     */
    AuthenticationService.prototype.logout = /**
     * @return {?}
     */
    function () {
        if (localStorage.getItem('token')) {
            localStorage.removeItem('token');
        }
        this.authenticatedUser = null;
        this.authenticated = false;
        this.authenticatedChanged.emit(false);
    };
    /**
     * @param {?} sharePointService
     * @param {?} token
     * @return {?}
     */
    AuthenticationService.prototype.validateUser = /**
     * @param {?} sharePointService
     * @param {?} token
     * @return {?}
     */
    function (sharePointService, token) {
        if (!token) {
            return;
        }
        var /** @type {?} */ jwtHelper = new JwtHelper();
        var /** @type {?} */ decoded = /** @type {?} */ (jwtHelper.decodeToken(token));
        if (jwtHelper.isTokenExpired(token)) {
            this.logout();
            return;
        }
        this.authenticatedUser = {
            admin: decoded.role === 'Admin',
            displayName: decoded.displayName,
            accountName: decoded.winaccountname,
            distinguishedName: decoded.distinguishedName,
            employeeNumber: decoded.employeeNumber
        };
        localStorage.setItem('token', token);
        this.getPhoto(sharePointService);
        this.authenticated = true;
        this.authenticatedChanged.emit(true);
    };
    /**
     * @param {?} sharePointService
     * @return {?}
     */
    AuthenticationService.prototype.getPhoto = /**
     * @param {?} sharePointService
     * @return {?}
     */
    function (sharePointService) {
        var _this = this;
        if (!this.authenticatedUser || !this.authenticatedUser.employeeNumber) {
            return;
        }
        sharePointService.getPhotos()
            .subscribe(function (photos) {
            var /** @type {?} */ photo = photos.find(function (pic) { return +pic.ows_EmployeeNumber === +_this.authenticatedUser.employeeNumber; });
            if (photo) {
                _this.authenticatedUser.photoUrl = photo.ows_EncodedAbsUrl;
            }
        });
    };
    //#endregion
    AuthenticationService.decorators = [
        { type: Injectable },
    ];
    /** @nocollapse */
    AuthenticationService.ctorParameters = function () { return [
        { type: AuthenticationServiceConfig, decorators: [{ type: Optional },] },
        { type: HttpClient, },
    ]; };
    AuthenticationService.propDecorators = {
        "authenticatedChanged": [{ type: Output },],
    };
    return AuthenticationService;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
//#region Imports
var EmailService = (function () {
    function EmailService(config, http$$1) {
        this.http = http$$1;
        this.emailServiceConfig = config;
    }
    /**
     * @param {?} email
     * @return {?}
     */
    EmailService.prototype.send = /**
     * @param {?} email
     * @return {?}
     */
    function (email) {
        var /** @type {?} */ dto = {
            server: this.emailServiceConfig.server,
            smtpPort: this.emailServiceConfig.smtpPort,
            sender: this.emailServiceConfig.sender,
            subject: email.subject,
            content: email.content,
            recipients: email.recipients
        };
        return this.http.post(this.emailServiceConfig.emailApiUrl, dto);
    };
    EmailService.decorators = [
        { type: Injectable },
    ];
    /** @nocollapse */
    EmailService.ctorParameters = function () { return [
        { type: EmailServiceConfig, decorators: [{ type: Optional },] },
        { type: HttpClient, },
    ]; };
    return EmailService;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
//#region Imports
var EmployeeService = (function () {
    //#endregion
    //#region Lifecycle
    function EmployeeService(config, http$$1) {
        this.http = http$$1;
        this.employeeApiUrl = config.employeeApiUrl;
    }
    //#endregion
    //#region Utilities
    /**
     * @param {?=} storeEmployees
     * @return {?}
     */
    EmployeeService.prototype.getEmployees = /**
     * @param {?=} storeEmployees
     * @return {?}
     */
    function (storeEmployees) {
        var _this = this;
        // Do we already have employees stored locally?
        if (this.employees) {
            return Observable$1.of(this.employees);
        }
        // Should we store employees locally for subsequent calls?
        if (storeEmployees) {
            this.http.get(this.employeeApiUrl)
                .subscribe(function (emps) { return _this.employees = emps; });
        }
        return this.http.get(this.employeeApiUrl);
    };
    /**
     * @param {?} sAMAccountName
     * @return {?}
     */
    EmployeeService.prototype.getEmployee = /**
     * @param {?} sAMAccountName
     * @return {?}
     */
    function (sAMAccountName) {
        return this.http.get(this.employeeApiUrl + "/name/" + sAMAccountName);
    };
    //#endregion
    EmployeeService.decorators = [
        { type: Injectable },
    ];
    /** @nocollapse */
    EmployeeService.ctorParameters = function () { return [
        { type: EmployeeServiceConfig, decorators: [{ type: Optional },] },
        { type: HttpClient, },
    ]; };
    return EmployeeService;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
//#region Imports
var SharePointService = (function () {
    //#endregion
    function SharePointService(config, http$$1) {
        this.http = http$$1;
        this.sharePointApiUrl = config.sharePointApiUrl;
    }
    //#region Utilities
    /**
     * @param {?} list
     * @return {?}
     */
    SharePointService.prototype.getListItems = /**
     * @param {?} list
     * @return {?}
     */
    function (list) {
        return this.http.post(this.sharePointApiUrl, list);
    };
    /**
     * @param {?} list
     * @param {?} view
     * @param {?=} site
     * @param {?=} limit
     * @return {?}
     */
    SharePointService.prototype.getListItemsSimple = /**
     * @param {?} list
     * @param {?} view
     * @param {?=} site
     * @param {?=} limit
     * @return {?}
     */
    function (list, view, site, limit) {
        return this.http.get(this.sharePointApiUrl + "/" + list + "/" + view + "/" + site + "/" + limit);
    };
    /**
     * @param {?=} storePeople
     * @return {?}
     */
    SharePointService.prototype.getPeople = /**
     * @param {?=} storePeople
     * @return {?}
     */
    function (storePeople) {
        var _this = this;
        // Do we already have people stored locally?
        if (this.people) {
            return Observable$1.of(this.people);
        }
        // Should we store people locally for subsequent calls?
        if (storePeople) {
            this.http.get(this.sharePointApiUrl + "/people")
                .subscribe(function (peeps) { return _this.people = peeps; });
        }
        return this.http.get(this.sharePointApiUrl + "/people");
    };
    /**
     * @param {?=} storePhotos
     * @return {?}
     */
    SharePointService.prototype.getPhotos = /**
     * @param {?=} storePhotos
     * @return {?}
     */
    function (storePhotos) {
        var _this = this;
        // Do we already have photos stored locally?
        if (this.photos) {
            return Observable$1.of(this.photos);
        }
        var /** @type {?} */ spList = {
            list: 'Employee Thumbnail Photos',
            view: 'All Pictures',
            site: 'http://cpsp1/DigitalDisplay'
        };
        // Should we store photos locally for subsequent calls?
        if (storePhotos) {
            this.http.post(this.sharePointApiUrl, spList)
                .subscribe(function (photos) { return _this.photos = photos; });
        }
        return this.http.post(this.sharePointApiUrl, spList);
    };
    //#endregion
    SharePointService.decorators = [
        { type: Injectable },
    ];
    /** @nocollapse */
    SharePointService.ctorParameters = function () { return [
        { type: SharePointServiceConfig, decorators: [{ type: Optional },] },
        { type: HttpClient, },
    ]; };
    return SharePointService;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var EmployeeByDnPipe = (function () {
    function EmployeeByDnPipe() {
    }
    /**
     * @param {?} dn
     * @param {?} employees
     * @return {?}
     */
    EmployeeByDnPipe.prototype.transform = /**
     * @param {?} dn
     * @param {?} employees
     * @return {?}
     */
    function (dn, employees) {
        return employees
            .find(function (emp) { return emp.distinguishedName.toLowerCase() === dn.toLowerCase(); });
    };
    EmployeeByDnPipe.decorators = [
        { type: Pipe, args: [{
                    name: 'employeeByDn'
                },] },
    ];
    /** @nocollapse */
    EmployeeByDnPipe.ctorParameters = function () { return []; };
    return EmployeeByDnPipe;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var IsMemberOfPipe = (function () {
    function IsMemberOfPipe() {
    }
    /**
     * @param {?} employee
     * @param {?} groupName
     * @return {?}
     */
    IsMemberOfPipe.prototype.transform = /**
     * @param {?} employee
     * @param {?} groupName
     * @return {?}
     */
    function (employee, groupName) {
        return employee.memberOf &&
            employee.memberOf.find(function (m) { return m.toLowerCase().indexOf(groupName) !== -1; }) !== null;
    };
    IsMemberOfPipe.decorators = [
        { type: Pipe, args: [{
                    name: 'isMemberOf'
                },] },
    ];
    /** @nocollapse */
    IsMemberOfPipe.ctorParameters = function () { return []; };
    return IsMemberOfPipe;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var PhotoUrlPipe = (function () {
    function PhotoUrlPipe() {
    }
    /**
     * @param {?} employee
     * @param {?} photos
     * @return {?}
     */
    PhotoUrlPipe.prototype.transform = /**
     * @param {?} employee
     * @param {?} photos
     * @return {?}
     */
    function (employee, photos) {
        if (!photos) {
            return null;
        }
        var /** @type {?} */ photo;
        // Try to match by employeeNumber, accountName, or title
        photos
            .filter(function (pic) {
            return (pic.ows_EmployeeNumber && employee.employeeNumber && +pic.ows_EmployeeNumber === +employee.employeeNumber) ||
                (pic.ows_AccountName && pic.ows_AccountName.toLowerCase() === employee.sAMAccountName.toLowerCase()) ||
                (pic.ows_Title && pic.ows_Title.toLowerCase() === employee.displayName.toLowerCase());
        })
            .forEach(function (pic) { return photo = pic; });
        if (!photo) {
            console.log("No photo match for " + employee.displayName);
        }
        return photo ? photo.ows_EncodedAbsUrl : null;
    };
    PhotoUrlPipe.decorators = [
        { type: Pipe, args: [{
                    name: 'photoUrl'
                },] },
    ];
    /** @nocollapse */
    PhotoUrlPipe.ctorParameters = function () { return []; };
    return PhotoUrlPipe;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var SortEmployeesPipe = (function () {
    function SortEmployeesPipe() {
    }
    /**
     * @param {?} employees
     * @param {?} filter
     * @param {?=} sortBy
     * @return {?}
     */
    SortEmployeesPipe.prototype.transform = /**
     * @param {?} employees
     * @param {?} filter
     * @param {?=} sortBy
     * @return {?}
     */
    function (employees, filter, sortBy) {
        if (sortBy === void 0) { sortBy = 'displayName'; }
        var /** @type {?} */ filtered = this.getFiltered(employees, filter);
        return this.getSorted(filtered, sortBy);
    };
    /**
     * @param {?} employees
     * @param {?} filter
     * @return {?}
     */
    SortEmployeesPipe.prototype.getFiltered = /**
     * @param {?} employees
     * @param {?} filter
     * @return {?}
     */
    function (employees, filter) {
        return filter ?
            employees
                .filter(function (emp) {
                return emp.displayName.toLowerCase().indexOf(filter.toLowerCase()) !== -1 ||
                    (emp.department && emp.department.toLowerCase().indexOf(filter.toLowerCase()) !== -1) ||
                    (emp.title && emp.title.toLowerCase().indexOf(filter.toLowerCase()) !== -1) ||
                    emp.sAMAccountName.toLowerCase().indexOf(filter.toLowerCase()) !== -1;
            }) :
            employees;
    };
    /**
     * @param {?} employees
     * @param {?} sortBy
     * @return {?}
     */
    SortEmployeesPipe.prototype.getSorted = /**
     * @param {?} employees
     * @param {?} sortBy
     * @return {?}
     */
    function (employees, sortBy) {
        return employees
            .sort(function (a, b) {
            if (a[sortBy] + a.displayName.toLowerCase() < b[sortBy] + b.displayName.toLowerCase()) {
                return -1;
            }
            if (a[sortBy] + a.displayName.toLowerCase() > b[sortBy] + b.displayName.toLowerCase()) {
                return 1;
            }
            return 0;
        });
    };
    SortEmployeesPipe.decorators = [
        { type: Pipe, args: [{
                    name: 'sortEmployees'
                },] },
    ];
    /** @nocollapse */
    SortEmployeesPipe.ctorParameters = function () { return []; };
    return SortEmployeesPipe;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
//#region Imports
// Service configurations
// Services
// Pipes
var EmailModule = (function () {
    function EmailModule(parentModule) {
        if (parentModule) {
            throw new Error('EmailModule is already loaded. Import it in the AppModule only');
        }
    }
    /**
     * @param {?} emailConfig
     * @return {?}
     */
    EmailModule.forRoot = /**
     * @param {?} emailConfig
     * @return {?}
     */
    function (emailConfig) {
        return {
            ngModule: EmailModule,
            providers: [
                EmailService,
                { provide: EmailServiceConfig, useValue: emailConfig }
            ]
        };
    };
    EmailModule.decorators = [
        { type: NgModule, args: [{
                    imports: [CommonModule],
                    declarations: [],
                    exports: []
                },] },
    ];
    /** @nocollapse */
    EmailModule.ctorParameters = function () { return [
        { type: EmailModule, decorators: [{ type: Optional }, { type: SkipSelf },] },
    ]; };
    return EmailModule;
}());
var SharePointModule = (function () {
    function SharePointModule(parentModule) {
        if (parentModule) {
            throw new Error('SharePointModule is already loaded. Import it in the AppModule only');
        }
    }
    /**
     * @param {?} sharePointConfig
     * @return {?}
     */
    SharePointModule.forRoot = /**
     * @param {?} sharePointConfig
     * @return {?}
     */
    function (sharePointConfig) {
        return {
            ngModule: SharePointModule,
            providers: [
                SharePointService,
                { provide: SharePointServiceConfig, useValue: sharePointConfig }
            ]
        };
    };
    SharePointModule.decorators = [
        { type: NgModule, args: [{
                    imports: [CommonModule],
                    declarations: [],
                    exports: []
                },] },
    ];
    /** @nocollapse */
    SharePointModule.ctorParameters = function () { return [
        { type: SharePointModule, decorators: [{ type: Optional }, { type: SkipSelf },] },
    ]; };
    return SharePointModule;
}());
var EmployeeModule = (function () {
    function EmployeeModule(parentModule) {
        if (parentModule) {
            throw new Error('EmployeeModule is already loaded. Import it in the AppModule only');
        }
    }
    /**
     * @param {?} employeeConfig
     * @return {?}
     */
    EmployeeModule.forRoot = /**
     * @param {?} employeeConfig
     * @return {?}
     */
    function (employeeConfig) {
        return {
            ngModule: EmployeeModule,
            providers: [
                EmployeeService,
                { provide: EmployeeServiceConfig, useValue: employeeConfig }
            ]
        };
    };
    EmployeeModule.decorators = [
        { type: NgModule, args: [{
                    imports: [CommonModule],
                    declarations: [
                        EmployeeByDnPipe,
                        IsMemberOfPipe,
                        PhotoUrlPipe,
                        SortEmployeesPipe
                    ],
                    exports: [
                        EmployeeByDnPipe,
                        IsMemberOfPipe,
                        PhotoUrlPipe,
                        SortEmployeesPipe
                    ]
                },] },
    ];
    /** @nocollapse */
    EmployeeModule.ctorParameters = function () { return [
        { type: EmployeeModule, decorators: [{ type: Optional }, { type: SkipSelf },] },
    ]; };
    return EmployeeModule;
}());
var AuthenticationModule = (function () {
    function AuthenticationModule(parentModule) {
        if (parentModule) {
            throw new Error('AuthenticationModule is already loaded. Import it in the AppModule only');
        }
    }
    /**
     * @param {?} authenticationConfig
     * @return {?}
     */
    AuthenticationModule.forRoot = /**
     * @param {?} authenticationConfig
     * @return {?}
     */
    function (authenticationConfig) {
        return {
            ngModule: AuthenticationModule,
            providers: [
                AuthenticationService,
                { provide: AuthenticationServiceConfig, useValue: authenticationConfig }
            ]
        };
    };
    AuthenticationModule.decorators = [
        { type: NgModule, args: [{
                    imports: [CommonModule],
                    declarations: [],
                    exports: []
                },] },
    ];
    /** @nocollapse */
    AuthenticationModule.ctorParameters = function () { return [
        { type: AuthenticationModule, decorators: [{ type: Optional }, { type: SkipSelf },] },
    ]; };
    return AuthenticationModule;
}());

//#endregion

export { EmailModule, SharePointModule, EmployeeModule, AuthenticationModule, AuthenticationServiceConfig, EmailServiceConfig, EmployeeServiceConfig, SharePointServiceConfig, AuthenticationService, EmailService, EmployeeService, SharePointService, EmployeeByDnPipe, IsMemberOfPipe, PhotoUrlPipe, SortEmployeesPipe };
